/* $Id: Direction.java 1591 2011-04-06 03:29:47Z terescoj $ */

/**
 * Class to represent snake's direction.
 * This is a very simple class.  Its only purpose is to
 * group together a horizontal and vertical speed into a 
 * pair so that we can treat them as a single object.
 *
 * @author Written by Tom Murtagh, Nov. 2001
 * @author Updated by Jim Teresco, April 2011
 */
public class Direction {
    
    // Constant names used to describe directions outside 
    // this class
    public static final Direction UP    = new Direction(0,-1);
    public static final Direction DOWN  = new Direction(0, 1);
    public static final Direction LEFT  = new Direction(-1,0);
    public static final Direction RIGHT = new Direction( 1,0);
    
    // The individual parts of the direction vector
    private int xChange;
    private int yChange;
    
    /**
     * Construct a new direction.
     *
     * @param xChange horizontal movement per cycle
     * @param yChange vertical movement per cycle
     */
    private Direction(int xChange, int yChange) {
        this.xChange = xChange;
        this.yChange = yChange;
    }
    
    /**
     * @return the horizontal component of velocity
     */
    public int getXChange() {
        return xChange;
    }
     
    /**
     * @return the vertical component of velocity
     */
    public int getYChange() {
        return yChange;
    }
    
    /**
     * Check if the given direction is the opposite of this one
     *
     * @param newDirection the direction to compare to
     *
     * @return whether the given direction is the opposite of this one
     */
    public boolean isOpposite(Direction newDirection) {
        return xChange == -newDirection.getXChange() &&
               yChange == -newDirection.getYChange();
    }
    
    /**
     * Return a string representation of a velocity so that 
     * it can be output meaningfully
     *
     * @return a printable string representation of the direction
     */
    public String toString () {
        return "(" + xChange + ", " + yChange + ")";
    }
}
