import objectdraw.*;
import java.awt.event.*;

/* $Id: Nibbles.java 1591 2011-04-06 03:29:47Z terescoj $ */

/**

 Game of Nibbles

 Plays the game of Nibbles.  It draws a snake on the screen and a
 piece of food.  The user uses the arrow keys to move the snake and
 try to eat the food.  The snake dies if it runs into the boundary or
 itself.

 @author J. Yang 2000
 @author Modified by A. Danyluk 2000
 @author Modified by Tom Murtagh Nov. 2001
 @author Modified by Jim Teresco, April 2011
*/
public class Nibbles extends WindowController implements KeyListener {
    
    // The snake that moves around.
    private Snake theSnake;
    
    // Remembers if there is a key depressed currently.
    private boolean keyDown = false;
    
    /**
     * Create the field, the snake, and set up for keyboard input
     */
    public void begin() {
        // build the field
        NibbleField field = new NibbleField(canvas);
        
        // create a snake with its head at a random location that is guaranteed
        // to allow the entire snake to fit in the field.
        theSnake = new Snake(field);
        
        // Get ready to handle the arrow keys
        requestFocus();
        addKeyListener(this);
        canvas.addKeyListener(this);
    }
    
    
    // Required by KeyListener Interface.
    public void keyTyped(KeyEvent e) { }
    
    // Remember that the key is no longer down.
    public void keyReleased(KeyEvent e) {
        keyDown = false;
    }
    
    /**
     * Handle the arrow keys by telling the snake to go in the
     * direction of the arrow.
     *
     * @param e the KeyEvent to translate into a snake direction
     */
    public void keyPressed(KeyEvent e) {
        if (!keyDown) {
            if (e.getKeyCode() == KeyEvent.VK_UP) {
                theSnake.setDirection(Direction.UP);
            } else if (e.getKeyCode() == KeyEvent.VK_DOWN) {
                theSnake.setDirection(Direction.DOWN);
            } else if (e.getKeyCode() == KeyEvent.VK_LEFT ) {
                theSnake.setDirection(Direction.LEFT);
            } else if (e.getKeyCode() == KeyEvent.VK_RIGHT ) {
                theSnake.setDirection(Direction.RIGHT);
            }
        }
      
        keyDown = true;  
    }
}
