/* $Id: Position.java 1594 2011-04-07 01:02:26Z terescoj $ */

/**
 * Class to represent a row, col position This is a very simple class.
 * It's only purpose is to group together a row and a column into a
 * pair so that we can treat them as a single object.
 *
 * @author A. Danyluk, April 2000
 * @author modifed by Tom Murtagh Nov. 2001
 * @author Modified by Jim Teresco, April 2011
 */
public class Position {
    
    // The individual parts of the row, col pair
    private int row;
    private int col;
    
    /**
     * Create a new position.
     *
     * @param row the row of the new position
     * @param col the column of the new position
     */
    public Position(int row, int col) {
        this.row = row;
        this.col = col;
    }
    
    /**
     * @return the row part of the pair
     */
    public int getRow() {
        return row;
    }
    
    /**
     * @return the column part of the pair
     */
    public int getCol() {
        return col;
    }

    /**
     * Determine if two Positions are equivalent
     *
     * @param pos the position that should be compared to "this" position
     *
     * @return whether pos is equivalent to this position
     */
    public boolean equals( Position pos ) {
        return row == pos.getRow() && col == pos.getCol() ;
    }
        
    /**
     * Determine the position reached if you move in the specified
     * Direction.
     *
     * @param dir the direction in which to move
     *
     * @return a new Position reached by a move in direction dir
     */
    public Position translate( Direction dir) {
        return new Position ( row + dir.getYChange(), col + dir.getXChange() );
    }
        
    /**
     * Return a string representation of the Position so that 
     * it can be output meaningfully
     *
     * @return a printable string representation of the position
     */
    public String toString () {
        return "(" + row + ", " + col + ")";
    }
}